==> reverse-ip-1.0.1.tar.gz: reverse-ip-1.0.1/src/reverseip/exceptions/error.py <==
from json import loads
from ..models.response import ErrorMessage

class ReverseIpApiError(Exception):
    def __init__(self, message):
        self.message = message

    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, message):
        self._message = message

    def __str__(self):
        return str(self.__dict__)


class ParameterError(ReverseIpApiError):
    pass


class EmptyApiKeyError(ReverseIpApiError):
    pass


class ResponseError(ReverseIpApiError):
    def __init__(self, message):
        self.message = message
        self._parsed_message = None
        try:
            parsed = loads(message)
            self.parsed_message = ErrorMessage(parsed)
        except Exception:
            pass

    @property
    def parsed_message(self):
        return self._parsed_message

    @parsed_message.setter
    def parsed_message(self, pm):
        self._parsed_message = pm


class UnparsableApiResponse(ReverseIpApiError):
    def __init__(self, message, origin_error):
        self.message = message
        self.original_error = origin_error

    @property
    def original_error(self):
        return self._original_error

    @original_error.setter
    def original_error(self, oe):
        self._original_error = oe


class ApiAuthError(ResponseError):
    pass


class BadRequestError(ResponseError):
    pass


class HttpApiError(ReverseIpApiError):
    pass


class CannotRetrieveNextPageError(ReverseIpApiError):
    pass

==> reverse-ip-1.1.0.tar.gz: reverse-ip-1.1.0/src/reverseip/exceptions/error.py <==
from json import loads
from ..models.response import ErrorMessage


class ReverseIpApiError(Exception):
    def __init__(self, message):
        self.message = message

    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, message):
        self._message = message

    def __str__(self):
        return str(self.__dict__)


class ParameterError(ReverseIpApiError):
    pass


class EmptyApiKeyError(ReverseIpApiError):
    pass


class ResponseError(ReverseIpApiError):
    def __init__(self, message):
        self.message = message
        self._parsed_message = None
        try:
            parsed = loads(message)
            self.parsed_message = ErrorMessage(parsed)
        except Exception:
            pass

    @property
    def parsed_message(self):
        return self._parsed_message

    @parsed_message.setter
    def parsed_message(self, pm):
        self._parsed_message = pm


class UnparsableApiResponseError(ReverseIpApiError):
    def __init__(self, message, origin_error):
        self.message = message
        self.original_error = origin_error

    @property
    def original_error(self):
        return self._original_error

    @original_error.setter
    def original_error(self, oe):
        self._original_error = oe


class ApiAuthError(ResponseError):
    pass


class BadRequestError(ResponseError):
    pass


class HttpApiError(ReverseIpApiError):
    pass


class CannotRetrieveNextPageError(ReverseIpApiError):
    pass
